==> ssp-center-api-0.6.49-yt-20200212.033859-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteMediaActivitySlotStatisticsStatService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.boot.netflix.feign.hystrix.FeignHystrixProperty;
import cn.com.duiba.boot.netflix.feign.hystrix.conf.HystrixPropertiesManager;
import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.tuia.ssp.center.api.dto.mediaapp.StatisticsCvrDto;
import cn.com.duiba.tuia.ssp.center.api.dto.mediaapp.StatisticsCvrRsp;
import cn.com.duiba.tuia.ssp.center.api.dto.mediaapp.StatisticsDateCvrDto;
import cn.com.duiba.tuia.ssp.center.api.dto.mediaapp.StatisticsDateCvrRsp;
import cn.com.duiba.tuia.ssp.center.api.params.RecommendSlotTagParam;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

@AdvancedFeignClient
public interface RemoteMediaActivitySlotStatisticsStatService {
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectSlotDataCount(ReqSlotStatDataByPage req);

    DubboResult<Integer> selectSlotDailyDataCount(ReqSlotStatDailyByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotData(ReqSlotStatDataByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<MeidaActivitySlotStatisticsDto> selectSumSlotData(ReqSlotStatDataByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotDailyData(ReqSlotStatDailyByPage req);

    DubboResult<Integer> updateSlotDailyData(ReqUpdateSlotDailyData req);

    DubboResult<Integer> batchUpdateSlotDailyData(List<ManualSlotDailyStatDto> req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotDailyDataBySlotAndDate(List<ManualSlotDailyStatDto> req);

    /**
     * 获取去媒体数据
     * @param req
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppData(ReqAppStatistics req);

    /**
     * 获取媒体数据的总计
     * @param req
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<MeidaActivitySlotStatisticsDto> selectAppSumData(ReqAppStatistics req);

    /**
     * 获取媒体数据数量，做分页用
     * @param req
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectAppDataCount(ReqAppStatistics req);

    /**
     * 获取媒体数据每日数据量
     * @param req
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectAppDailyDataCount(ReqAppDailyStatistics req);

    /**
     * 获取媒体数据每日数据
     * @param req
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppDailyData(ReqAppDailyStatistics req);

    DubboResult<Integer> selectAppSlotDailyCount(ReqAppSlotDailyStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppSlotDailyData(ReqAppSlotDailyStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppSlotData(ReqAppSlotStatistics req);

    DubboResult<MeidaActivitySlotStatisticsDto> selectAppSlotSumData(ReqAppSlotStatistics req);

    DubboResult<Integer> selectAppSlotDataCount(ReqAppSlotStatistics req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectChangeSlotTotalData(ReqAppStatistics req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<MeidaActivitySlotStatisticsDto> selectChangeSlotTotalSumData(ReqAppStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectChangeSlotDailyData(ReqAppDailyStatistics req);

    DubboResult<Integer> selectActivityMediaSoltAmount(ReqActivitySlotDataByPage param);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectActivitySoltAmount(ReqActivitySlotDataByPage param);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<ActivitySlotCountDto> selectBatchActivitySoltAmount(ReqActivitySlotDataByPage reqActivitySlotDataByPage);

    DubboResult<Integer> selectActivitySoltDailyAmount(ReqActivitySlotDataByPage param);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectActivityStatCount(ReqActivityStatDataByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivityStatData(ReqActivityStatDataByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<MeidaActivitySlotStatisticsDto> selectActivityStatDataByActIds(ReqActivityStatDataByPage reqActivityStatDataByPage);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<MeidaActivitySlotStatisticsDto> selectActivityStatSumData(ReqActivityStatDataByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectActAppStatCount(ReqActAppStatDataByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActAppStatData(ReqActAppStatDataByPage req);

    DubboResult<MeidaActivitySlotStatisticsDto> selectActAppStatSumData(ReqActAppStatDataByPage req);

    DubboResult<Integer> selectActAppStatDailyCount(ReqActAppStatDailyByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActAppStatDailyData(ReqActAppStatDailyByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivityMediaSoltDataByPage(ReqActivitySlotDataByPage param);

    DubboResult<MeidaActivitySlotStatisticsDto> selectActivityMediaSoltSumData(ReqActivitySlotDataByPage param);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivitySoltDataByPage(ReqActivitySlotDataByPage param);

    DubboResult<MeidaActivitySlotStatisticsDto> selectActivitySoltSumData(ReqActivitySlotDataByPage param);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivitySoltDailyByPage(ReqActivitySlotDataByPage param);

    DubboResult<MeidaActivitySlotStatisticsDto> selectSlotDailyDataById(Long id);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotActByPage(ReqActivitySlotDataByPage req);

    DubboResult<MeidaActivitySlotStatisticsDto> selectSlotActTotal(ReqActivitySlotDataByPage req);

    DubboResult<Integer> selectSlotActAmount(ReqActivitySlotDataByPage req);

    /**
     *
     * selectActivityDailyAmount:(查询活动每日数据数量). <br/>
     *
     * @author guyan
     * @param req
     * @return
     * @since JDK 1.6
     */
    DubboResult<Integer>  selectActivityDailyAmount(ReqActDailyStatDataByPage req);

    /**
     *
     * selectActivityDailyData:(查询活动每日数据). <br/>
     *
     * @author guyan
     * @param req
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<MeidaActivitySlotStatisticsDto>>  selectActivityDailyData(ReqActDailyStatDataByPage req);

    /**
     * 查询app的cvr值
     * @param statisticsCvrRsp
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<StatisticsCvrDto> selectAppStatisticsCvrDto(StatisticsCvrRsp statisticsCvrRsp);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<StatisticsDateCvrDto> selectAppDateStatisticsCvrDto(StatisticsDateCvrRsp statisticsCvrRsp);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<StatisticsCvrDto> selectSlotStatisticsCvrDto(StatisticsCvrRsp statisticsCvrRsp);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<StatisticsDateCvrDto> selectSlotDateStatisticsCvrDto(StatisticsDateCvrRsp statisticsCvrRsp);


    /**
     * 获取活动的推荐广告位性质
     * @param statisticsCvrRsp
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<SlotTypeActivityGreaterDto> selectRecommendSlotTagByActIds(RecommendSlotTagParam param);

    /**
     * 根据条件分页查询广告位素材数据
     */
    List<MaterialDataDTO> listSlotMaterialData(ReqSlotMaterialData reqSlotMaterialData);

    /**
     * 根据条件查询广告位素材数据数目
     */
    int countSlotMaterialData(ReqSlotMaterialData reqSlotMaterialData);

    /**
     * 根据条件分页查询广告位素材每日数据
     */
    List<MaterialDataDTO> listSlotMaterialDayData(ReqSlotMaterialData reqSlotMaterialData);

    /**
     * 根据条件查询广告位素材每日数据数目
     */
    int countSlotMaterialDayData(ReqSlotMaterialData reqSlotMaterialData);
}

==> ssp-center-api-0.7.11-yt-20200527.111908-3-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteMediaActivitySlotStatisticsStatService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.boot.netflix.feign.hystrix.FeignHystrixProperty;
import cn.com.duiba.boot.netflix.feign.hystrix.conf.HystrixPropertiesManager;
import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.tuia.ssp.center.api.dto.mediaapp.StatisticsCvrDto;
import cn.com.duiba.tuia.ssp.center.api.dto.mediaapp.StatisticsCvrRsp;
import cn.com.duiba.tuia.ssp.center.api.dto.mediaapp.StatisticsDateCvrDto;
import cn.com.duiba.tuia.ssp.center.api.dto.mediaapp.StatisticsDateCvrRsp;
import cn.com.duiba.tuia.ssp.center.api.params.RecommendSlotTagParam;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;
import java.util.Map;

@AdvancedFeignClient
public interface RemoteMediaActivitySlotStatisticsStatService {
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectSlotDataCount(ReqSlotStatDataByPage req);

    DubboResult<Integer> selectSlotDailyDataCount(ReqSlotStatDailyByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotData(ReqSlotStatDataByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<MeidaActivitySlotStatisticsDto> selectSumSlotData(ReqSlotStatDataByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotDailyData(ReqSlotStatDailyByPage req);

    DubboResult<Integer> updateSlotDailyData(ReqUpdateSlotDailyData req);

    DubboResult<Integer> batchUpdateSlotDailyData(List<ManualSlotDailyStatDto> req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotDailyDataBySlotAndDate(List<ManualSlotDailyStatDto> req);

    /**
     * 获取去媒体数据
     * @param req
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppData(ReqAppStatistics req);

    /**
     * 获取媒体数据的总计
     * @param req
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<MeidaActivitySlotStatisticsDto> selectAppSumData(ReqAppStatistics req);

    /**
     * 获取媒体数据数量，做分页用
     * @param req
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectAppDataCount(ReqAppStatistics req);

    /**
     * 获取媒体数据每日数据量
     * @param req
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectAppDailyDataCount(ReqAppDailyStatistics req);

    /**
     * 获取媒体数据每日数据
     * @param req
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppDailyData(ReqAppDailyStatistics req);

    DubboResult<Integer> selectAppSlotDailyCount(ReqAppSlotDailyStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppSlotDailyData(ReqAppSlotDailyStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppSlotData(ReqAppSlotStatistics req);

    DubboResult<MeidaActivitySlotStatisticsDto> selectAppSlotSumData(ReqAppSlotStatistics req);

    DubboResult<Integer> selectAppSlotDataCount(ReqAppSlotStatistics req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectChangeSlotTotalData(ReqAppStatistics req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<MeidaActivitySlotStatisticsDto> selectChangeSlotTotalSumData(ReqAppStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectChangeSlotDailyData(ReqAppDailyStatistics req);

    DubboResult<Integer> selectActivityMediaSoltAmount(ReqActivitySlotDataByPage param);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectActivitySoltAmount(ReqActivitySlotDataByPage param);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<ActivitySlotCountDto> selectBatchActivitySoltAmount(ReqActivitySlotDataByPage reqActivitySlotDataByPage);

    DubboResult<Integer> selectActivitySoltDailyAmount(ReqActivitySlotDataByPage param);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectActivityStatCount(ReqActivityStatDataByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivityStatData(ReqActivityStatDataByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<MeidaActivitySlotStatisticsDto> selectActivityStatDataByActIds(ReqActivityStatDataByPage reqActivityStatDataByPage);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<MeidaActivitySlotStatisticsDto> selectActivityStatSumData(ReqActivityStatDataByPage req);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<Integer> selectActAppStatCount(ReqActAppStatDataByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActAppStatData(ReqActAppStatDataByPage req);

    DubboResult<MeidaActivitySlotStatisticsDto> selectActAppStatSumData(ReqActAppStatDataByPage req);

    DubboResult<Integer> selectActAppStatDailyCount(ReqActAppStatDailyByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActAppStatDailyData(ReqActAppStatDailyByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivityMediaSoltDataByPage(ReqActivitySlotDataByPage param);

    DubboResult<MeidaActivitySlotStatisticsDto> selectActivityMediaSoltSumData(ReqActivitySlotDataByPage param);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivitySoltDataByPage(ReqActivitySlotDataByPage param);

    DubboResult<MeidaActivitySlotStatisticsDto> selectActivitySoltSumData(ReqActivitySlotDataByPage param);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivitySoltDailyByPage(ReqActivitySlotDataByPage param);

    DubboResult<MeidaActivitySlotStatisticsDto> selectSlotDailyDataById(Long id);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotActByPage(ReqActivitySlotDataByPage req);

    DubboResult<MeidaActivitySlotStatisticsDto> selectSlotActTotal(ReqActivitySlotDataByPage req);

    DubboResult<Integer> selectSlotActAmount(ReqActivitySlotDataByPage req);

    /**
     *
     * selectActivityDailyAmount:(查询活动每日数据数量). <br/>
     *
     * @author guyan
     * @param req
     * @return
     * @since JDK 1.6
     */
    DubboResult<Integer>  selectActivityDailyAmount(ReqActDailyStatDataByPage req);

    /**
     *
     * selectActivityDailyData:(查询活动每日数据). <br/>
     *
     * @author guyan
     * @param req
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<MeidaActivitySlotStatisticsDto>>  selectActivityDailyData(ReqActDailyStatDataByPage req);

    /**
     * 查询app的cvr值
     * @param statisticsCvrRsp
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<StatisticsCvrDto> selectAppStatisticsCvrDto(StatisticsCvrRsp statisticsCvrRsp);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<StatisticsDateCvrDto> selectAppDateStatisticsCvrDto(StatisticsDateCvrRsp statisticsCvrRsp);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<StatisticsCvrDto> selectSlotStatisticsCvrDto(StatisticsCvrRsp statisticsCvrRsp);

    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<StatisticsDateCvrDto> selectSlotDateStatisticsCvrDto(StatisticsDateCvrRsp statisticsCvrRsp);


    /**
     * 获取活动的推荐广告位性质
     * @param statisticsCvrRsp
     * @return
     */
    @FeignHystrixProperty(name = HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value = "30000")
    List<SlotTypeActivityGreaterDto> selectRecommendSlotTagByActIds(RecommendSlotTagParam param);

    /**
     * 根据条件分页查询广告位素材数据
     */
    List<MaterialDataDTO> listSlotMaterialData(ReqSlotMaterialData reqSlotMaterialData);

    /**
     * 根据条件查询广告位素材数据数目
     */
    int countSlotMaterialData(ReqSlotMaterialData reqSlotMaterialData);

    /**
     * 根据条件分页查询广告位素材每日数据
     */
    List<MaterialDataDTO> listSlotMaterialDayData(ReqSlotMaterialData reqSlotMaterialData);

    /**
     * 根据条件查询广告位素材每日数据数目
     */
    int countSlotMaterialDayData(ReqSlotMaterialData reqSlotMaterialData);

    /**
     * 近三日媒体uv单价均值 广告位维度
     * @param req
     * @return
     */
    List<AppSlotAvgUvDto> selectAvgMediaUvByDate(ReqMediaAvgUvStatistics req);

    /**
     * 根据查询条件查处 广告消耗 含增值 媒体维度返回 map的形式返回
     * @param req
     * @return
     */
    Map<Long,Long> selectAppAddedConsume(ReqAppDayBillByPage req);

    /**
     * 根据查询条件查处 广告消耗 含增值 广告位维度返回 map的形式返回
     * @param req
     * @return
     */
    Map<Long,Long> selectSlotAddedConsume(ReqAppDayBillByPage req);

    /**
     * 根据查询条件查处 广告消耗 含增值 广告位维度返回 map的形式返回 加上日期维度
     * @param req
     * @return
     */
    Map<String,Long> selectSlotAddedConsumeByCurDate(ReqAppDayBillByPage req);

    /**
     * 根据查询条件查处 广告消耗 含增值 广告位维度返回 map的形式返回 加上日期维度
     * @param req
     * @return
     */
    Map<String,Long> selectAppAddedConsumeByCurDate(ReqAppDayBillByPage req);

    /**
     * 近几日无消耗
     * @param days 天数
     * @param adConsumeLimit 小于多少金额
     * @return 账号列表
     */
    List<Long> listNoAdConsumeByDays(int days, int adConsumeLimit);

    /**
     * 查询有消耗账号数据列表
     */
    List<MeidaActivitySlotStatisticsDto> listAdConsumeByMediaIds(ReqAppDayBillByPage req);
}
